==> keyclic_sdk_api-1.32.9-beta.tar.gz: lib/model/operation.dart <==
part of keyclic_sdk_api.api;

class Operation {
  String description = null;

  int duration = null;

  String name = null;

  DateTime startDate = null;

  String id = null;

  String identificationNumber = null;

  List<String> state = [];

  DateTime createdAt = null;

  DateTime updatedAt = null;

  String type = null;

  OperationLinks links = null;

  FeedbackEmbedded embedded = null;

  Operation();

  @override
  String toString() {
    return 'Operation[description=$description, duration=$duration, name=$name, startDate=$startDate, id=$id, identificationNumber=$identificationNumber, state=$state, createdAt=$createdAt, updatedAt=$updatedAt, type=$type, links=$links, embedded=$embedded, ]';
  }

  Operation.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    description = json['description'];
    duration = json['duration'];
    name = json['name'];
    startDate =
        json['startDate'] == null ? null : DateTime.parse(json['startDate']);
    id = json['id'];
    identificationNumber = json['identificationNumber'];
    state = (json['state'] as List)?.map((item) => item as String)?.toList();
    createdAt =
        json['createdAt'] == null ? null : DateTime.parse(json['createdAt']);
    updatedAt =
        json['updatedAt'] == null ? null : DateTime.parse(json['updatedAt']);
    type = json['type'];
    links = new OperationLinks.fromJson(json['_links']);
    embedded = new FeedbackEmbedded.fromJson(json['_embedded']);
  }

  Map<String, dynamic> toJson() {
    return {
      'description': description,
      'duration': duration,
      'name': name,
      'startDate': startDate == null ? '' : startDate.toUtc().toIso8601String(),
      'id': id,
      'identificationNumber': identificationNumber,
      'state': state,
      'createdAt': createdAt == null ? '' : createdAt.toUtc().toIso8601String(),
      'updatedAt': updatedAt == null ? '' : updatedAt.toUtc().toIso8601String(),
      'type': type,
      '_links': links,
      '_embedded': embedded,
    };
  }

  static List<Operation> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<Operation>()
        : json.map((value) => new Operation.fromJson(value)).toList();
  }

  static Map<String, Operation> mapFromJson(Map<String, dynamic> json) {
    var map = new Map<String, Operation>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new Operation.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.35.3-beta.tar.gz: lib/model/operation.dart <==
part of keyclic_sdk_api.api;

class Operation {
  String description = null;

  String name = null;

  DateTime scheduledAt = null;

  String id = null;

  String identificationNumber = null;

  List<String> state = [];

  DateTime createdAt = null;

  DateTime updatedAt = null;

  String type = null;

  OperationLinks links = null;

  FeedbackEmbedded embedded = null;

  Operation();

  @override
  String toString() {
    return 'Operation[description=$description, name=$name, scheduledAt=$scheduledAt, id=$id, identificationNumber=$identificationNumber, state=$state, createdAt=$createdAt, updatedAt=$updatedAt, type=$type, links=$links, embedded=$embedded, ]';
  }

  Operation.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    description = json['description'];
    name = json['name'];
    scheduledAt = json['scheduledAt'] == null
        ? null
        : DateTime.parse(json['scheduledAt']);
    id = json['id'];
    identificationNumber = json['identificationNumber'];
    state = (json['state'] as List)?.map((item) => item as String)?.toList();
    createdAt =
        json['createdAt'] == null ? null : DateTime.parse(json['createdAt']);
    updatedAt =
        json['updatedAt'] == null ? null : DateTime.parse(json['updatedAt']);
    type = json['type'];
    links = new OperationLinks.fromJson(json['_links']);
    embedded = new FeedbackEmbedded.fromJson(json['_embedded']);
  }

  Map<String, dynamic> toJson() {
    return {
      'description': description,
      'name': name,
      'scheduledAt':
          scheduledAt == null ? '' : scheduledAt.toUtc().toIso8601String(),
      'id': id,
      'identificationNumber': identificationNumber,
      'state': state,
      'createdAt': createdAt == null ? '' : createdAt.toUtc().toIso8601String(),
      'updatedAt': updatedAt == null ? '' : updatedAt.toUtc().toIso8601String(),
      'type': type,
      '_links': links,
      '_embedded': embedded,
    };
  }

  static List<Operation> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<Operation>()
        : json.map((value) => new Operation.fromJson(value)).toList();
  }

  static Map<String, Operation> mapFromJson(Map<String, dynamic> json) {
    var map = new Map<String, Operation>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new Operation.fromJson(value));
    }
    return map;
  }
}
